TlGeofenceEvent class

Constructors

TlGeofenceEvent({required String identifier, required TlGeofenceAction action, required TlLocation location, Map<String?, Object?>? extras})

Properties

action ↔ TlGeofenceAction
getter/setter pair
extras ↔ Map<String?, Object?>?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
identifier ↔ String
getter/setter pair
location ↔ TlLocation
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → TlGeofenceEvent