getAuditProof method

Future<Map<String, Object?>?> getAuditProof(
  1. String uuid
)

Get the audit proof for a specific location record by uuid.

Returns null if audit trail is disabled or the record does not exist.

Implementation

Future<Map<String, Object?>?> getAuditProof(String uuid) {
  throw UnimplementedError('getAuditProof() has not been implemented.');
}