TlHttpConfig class
Constructors
-
TlHttpConfig({String? url, TlHttpMethod? method, Map<
String?, String?> ? headers, Map<String?, Object?> ? params, bool? autoSync, bool? batchSync, int? maxBatchSize, List<String?> ? sslPinningFingerprints, List<String?> ? sslPinningCertificates, String? httpRootProperty, int? autoSyncThreshold, int? autoSyncDelay, int? syncInterval, int? httpTimeout, TlLocationOrderDirection? locationsOrderDirection, Map<String?, Object?> ? extras, bool? disableAutoSyncOnCellular, int? maxRetries, int? retryBackoffBase, int? retryBackoffCap, bool? enableDeltaCompression, int? deltaCoordinatePrecision, bool? syncTelematics, String? telematicsUrl})
Properties
- autoSync ↔ bool?
-
getter/setter pair
- autoSyncDelay ↔ int?
-
getter/setter pair
- autoSyncThreshold ↔ int?
-
getter/setter pair
- batchSync ↔ bool?
-
getter/setter pair
- deltaCoordinatePrecision ↔ int?
-
getter/setter pair
- disableAutoSyncOnCellular ↔ bool?
-
getter/setter pair
- enableDeltaCompression ↔ bool?
-
getter/setter pair
-
extras
↔ Map<
String?, Object?> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
headers
↔ Map<
String?, String?> ? -
getter/setter pair
- httpRootProperty ↔ String?
-
getter/setter pair
- httpTimeout ↔ int?
-
getter/setter pair
- locationsOrderDirection ↔ TlLocationOrderDirection?
-
getter/setter pair
- maxBatchSize ↔ int?
-
getter/setter pair
- maxRetries ↔ int?
-
getter/setter pair
- method ↔ TlHttpMethod?
-
getter/setter pair
-
params
↔ Map<
String?, Object?> ? -
getter/setter pair
- retryBackoffBase ↔ int?
-
getter/setter pair
- retryBackoffCap ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sslPinningCertificates
↔ List<
String?> ? -
getter/setter pair
-
sslPinningFingerprints
↔ List<
String?> ? -
getter/setter pair
- syncInterval ↔ int?
-
getter/setter pair
- syncTelematics ↔ bool?
-
getter/setter pair
- telematicsUrl ↔ String?
-
getter/setter pair
- url ↔ String?
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → TlHttpConfig