TlLocation class

A location fix returned from the native platform.

Constructors

TlLocation({required TlCoords coords, required TlBattery battery, required String timestamp, required String uuid, required bool isMoving, required double odometer, String? event, TlActivity? activity, Map<String?, Object?>? extras})

Properties

activity TlActivity?
getter/setter pair
battery TlBattery
getter/setter pair
coords TlCoords
getter/setter pair
event String?
getter/setter pair
extras Map<String?, Object?>?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isMoving bool
getter/setter pair
odometer double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
getter/setter pair
uuid String
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) TlLocation