TlPersistenceConfig class
Constructors
- TlPersistenceConfig({required TlPersistMode persistMode, required int maxDaysToPersist, required int maxRecordsToPersist, required bool disableProviderChangeRecord})
Properties
- disableProviderChangeRecord ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxDaysToPersist ↔ int
-
getter/setter pair
- maxRecordsToPersist ↔ int
-
getter/setter pair
- persistMode ↔ TlPersistMode
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → TlPersistenceConfig