TraceletHostApi class
Constructors
TraceletHostApi ({BinaryMessenger ? binaryMessenger , String messageChannelSuffix = '' })
Constructor for TraceletHostApi . The binaryMessenger named argument is
available for dependency injection. If it is left null, the default
BinaryMessenger will be used which routes to the host platform.
Methods
addGeofence (TlGeofence geofence )
→ Future <bool >
addGeofences (List <TlGeofence > geofences )
→ Future <bool >
addPrivacyZone (Map <String ? , Object ? > zone )
→ Future <bool >
addPrivacyZones (List <Map <String ? , Object ? > ? > zones )
→ Future <bool >
canScheduleExactAlarms ()
→ Future <bool >
changePace (bool isMoving )
→ Future <bool >
clearRouteContext ()
→ Future <bool >
destroyLocation (String uuid )
→ Future <bool >
destroyLocations ()
→ Future <bool >
destroyLog ()
→ Future <bool >
destroySyncedLocations ()
→ Future <int >
emailLog (String email )
→ Future <bool >
encryptDatabase ()
→ Future <bool >
geofenceExists (String identifier )
→ Future <bool >
getAttestationToken ()
→ Future <Map <String ? , Object ? > ? >
getAuditProof (String uuid )
→ Future <Map <String ? , Object ? > ? >
getCarbonReport (Map <String ? , Object ? > ? query )
→ Future <Map <String ? , Object ? > >
getCount (Map <String ? , Object ? > ? query )
→ Future <int >
getCurrentPosition (TlCurrentPositionOptions options )
→ Future <TlLocation >
getDeadReckoningState ()
→ Future <Map <String ? , Object ? > ? >
getDeviceInfo ()
→ Future <Map <String ? , Object ? > >
getGeofence (String identifier )
→ Future <TlGeofence ? >
getGeofences ()
→ Future <List <TlGeofence ? > >
getLastKnownLocation (TlCurrentPositionOptions ? options )
→ Future <TlLocation ? >
getLocations (Map <String ? , Object ? > ? query )
→ Future <List <TlLocation ? > >
getLog (Map <String ? , Object ? > ? query )
→ Future <String >
getMotionPermissionStatus ()
→ Future <int >
getNotificationPermissionStatus ()
→ Future <int >
getOdometer ()
→ Future <double >
getPermissionStatus ()
→ Future <TlAuthorizationStatus >
getPrivacyZones ()
→ Future <List <Map <String ? , Object ? > ? > >
getProviderState ()
→ Future <TlProviderChangeEvent >
getSensors ()
→ Future <Map <String ? , Object ? > >
getSettingsHealth ()
→ Future <Map <String ? , Object ? > >
getState ()
→ Future <TlState >
insertLocation (Map <String ? , Object ? > params )
→ Future <String >
isDatabaseEncrypted ()
→ Future <bool >
isIgnoringBatteryOptimizations ()
→ Future <bool >
isPowerSaveMode ()
→ Future <bool >
log (String level , String message )
→ Future <bool >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openExactAlarmSettings ()
→ Future <bool >
openOemSettings (String label )
→ Future <bool >
playSound (String name )
→ Future <bool >
ready (TlConfig config )
→ Future <TlState >
registerHeadlessSyncBodyBuilder (List <int ? > callbackIds )
→ Future <bool >
registerHeadlessTask (List <int ? > callbackIds )
→ Future <bool >
removeGeofence (String identifier )
→ Future <bool >
removeGeofences ()
→ Future <bool >
removePrivacyZone (String identifier )
→ Future <bool >
removePrivacyZones ()
→ Future <bool >
requestMotionPermission ()
→ Future <int >
requestNotificationPermission ()
→ Future <int >
requestPermission ()
→ Future <TlAuthorizationStatus >
requestSettings (String action )
→ Future <bool >
requestTemporaryFullAccuracy (String purpose )
→ Future <int >
reset (TlConfig ? config )
→ Future <TlState >
setConfig (TlConfig config )
→ Future <TlState >
setOdometer (double value )
→ Future <TlLocation >
setRouteContext (Map <String ? , Object ? > context )
→ Future <bool >
showSettings (String action )
→ Future <bool >
start ()
→ Future <TlState >
startBackgroundTask ()
→ Future <int >
startGeofences ()
→ Future <TlState >
startPeriodic ()
→ Future <TlState >
startSchedule ()
→ Future <TlState >
stop ()
→ Future <TlState >
stopBackgroundTask (int taskId )
→ Future <int >
stopSchedule ()
→ Future <TlState >
stopWatchPosition (int watchId )
→ Future <bool >
sync ()
→ Future <List <TlLocation ? > >
toString ()
→ String
A string representation of this object.
inherited
verifyAuditTrail ()
→ Future <Map <String ? , Object ? > >
watchPosition (TlCurrentPositionOptions options )
→ Future <int >
tracelet_platform_interface 2.0.0