getAuditProof method
Get the audit proof for a specific location record by uuid.
Returns null if audit trail is disabled or the record does not exist.
Implementation
Future<Map<String, Object?>?> getAuditProof(String uuid) {
throw UnimplementedError('getAuditProof() has not been implemented.');
}